@@ -3,6 +3,7 @@
 "Account"
 from trytond.model import ModelView, ModelSQL, fields
 from trytond.wizard import Wizard
+from trytond.pyson import Equal, Eval, Not, PYSONEncoder
 from decimal import Decimal
 import copy
 
@@ -17,8 +18,8 @@ class Account(ModelSQL, ModelView):
     active = fields.Boolean('Active', select=2)
     company = fields.Many2One('company.company', 'Company')
     currency = fields.Many2One('currency.currency', 'Currency', required=True)
-    currency_digits = fields.Function('get_currency_digits', type='integer',
-            string='Currency Digits', on_change_with=['currency'])
+    currency_digits = fields.Function(fields.Integer('Currency Digits',
+        on_change_with=['currency']), 'get_currency_digits')
     type = fields.Selection([
         ('root', 'Root'),
         ('view', 'View'),
@@ -27,22 +28,25 @@ class Account(ModelSQL, ModelView):
     root = fields.Many2One('analytic_account.account', 'Root', select=2,
             domain=[('parent', '=', False)],
             states={
-                'invisible': "type == 'root'",
-                'required': "type != 'root'",
+                'invisible': Equal(Eval('type'), 'root'),
+                'required': Not(Equal(Eval('type'), 'root')),
             })
     parent = fields.Many2One('analytic_account.account', 'Parent', select=2,
-            domain=["('parent', 'child_of', root)"],
+            domain=[('parent', 'child_of', Eval('root'))],
             states={
-                'invisible': "type == 'root'",
-                'required': "type != 'root'",
+                'invisible': Equal(Eval('type'), 'root'),
+                'required': Not(Equal(Eval('type'), 'root')),
             })
     childs = fields.One2Many('analytic_account.account', 'parent', 'Children')
-    balance = fields.Function('get_balance', digits="(16, currency_digits)",
-            string='Balance')
-    credit = fields.Function('get_credit_debit', digits="(16, currency_digits)",
-            string='Credit')
-    debit = fields.Function('get_credit_debit', digits="(16, currency_digits)",
-            string='Debit')
+    balance = fields.Function(fields.Numeric('Balance',
+        digits=(16, Eval('currency_digits', 1)), depends=['currency_digits']),
+        'get_balance')
+    credit = fields.Function(fields.Numeric('Credit',
+        digits=(16, Eval('currency_digits', 2)), depends=['currency_digits']),
+        'get_credit_debit')
+    debit = fields.Function(fields.Numeric('Debit',
+        digits=(16, Eval('currency_digits', 2)), depends=['currency_digits']),
+        'get_credit_debit')
     state = fields.Selection([
         ('draft', 'Draft'),
         ('opened', 'Opened'),
@@ -54,7 +58,7 @@ class Account(ModelSQL, ModelView):
         ('credit-debit', 'Credit - Debit'),
         ], 'Display Balance', required=True)
     mandatory = fields.Boolean('Mandatory', states={
-        'invisible': "type != 'root'",
+        'invisible': Not(Equal(Eval('type'), 'root')),
         })
 
     def __init__(self):
@@ -71,7 +75,6 @@ class Account(ModelSQL, ModelView):
         return True
 
     def default_company(self, cursor, user, context=None):
-        company_obj = self.pool.get('company.company')
         if context is None:
             context = {}
         if context.get('company'):
@@ -101,8 +104,7 @@ class Account(ModelSQL, ModelView):
     def default_mandatory(self, cursor, user, context=None):
         return False
 
-    def on_change_with_currency_digits(self, cursor, user, ids, vals,
-            context=None):
+    def on_change_with_currency_digits(self, cursor, user, vals, context=None):
         currency_obj = self.pool.get('currency.currency')
         if vals.get('currency'):
             currency = currency_obj.browse(cursor, user, vals['currency'],
@@ -110,13 +112,13 @@ class Account(ModelSQL, ModelView):
             return currency.digits
         return 2
 
-    def get_currency_digits(self, cursor, user, ids, name, arg, context=None):
+    def get_currency_digits(self, cursor, user, ids, name, context=None):
         res = {}
         for account in self.browse(cursor, user, ids, context=context):
             res[account.id] = account.currency.digits
         return res
 
-    def get_balance(self, cursor, user, ids, name, arg, context=None):
+    def get_balance(self, cursor, user, ids, name, context=None):
         res = {}
         line_obj = self.pool.get('analytic_account.line')
         currency_obj = self.pool.get('currency.currency')
@@ -185,7 +187,7 @@ class Account(ModelSQL, ModelView):
                 res[account_id] = - res[account_id]
         return res
 
-    def get_credit_debit(self, cursor, user, ids, name, arg, context=None):
+    def get_credit_debit(self, cursor, user, ids, name, context=None):
         res = {}
         line_obj = self.pool.get('analytic_account.line')
         currency_obj = self.pool.get('currency.currency')
@@ -237,7 +239,7 @@ class Account(ModelSQL, ModelView):
                         id2account[account_id].currency, sum)
         return res
 
-    def get_rec_name(self, cursor, user, ids, name, arg, context=None):
+    def get_rec_name(self, cursor, user, ids, name, context=None):
         if not ids:
             return {}
         res = {}
@@ -248,18 +250,13 @@ class Account(ModelSQL, ModelView):
                 res[account.id] = unicode(account.name)
         return res
 
-    def search_rec_name(self, cursor, user, name, args, context=None):
-        args2 = []
-        i = 0
-        while i < len(args):
-            ids = self.search(cursor, user, [('code', args[i][1], args[i][2])],
-                    limit=1, context=context)
-            if ids:
-                args2.append(('code', args[i][1], args[i][2]))
-            else:
-                args2.append((self._rec_name, args[i][1], args[i][2]))
-            i += 1
-        return args2
+    def search_rec_name(self, cursor, user, name, clause, context=None):
+        ids = self.search(cursor, user, [('code',) + clause[1:]], limit=1,
+                context=context)
+        if ids:
+            return [('code',) + clause[1:]]
+        else:
+            return [(self._rec_name,) + clause[1:]]
 
     def convert_view(self, cursor, user, tree, context=None):
         res = tree.xpath('//field[@name=\'analytic_accounts\']')
@@ -345,18 +342,12 @@ class OpenChartAccount(Wizard):
     def _action_open_chart(self, cursor, user, data, context=None):
         model_data_obj = self.pool.get('ir.model.data')
         act_window_obj = self.pool.get('ir.action.act_window')
-
-        model_data_ids = model_data_obj.search(cursor, user, [
-            ('fs_id', '=', 'act_account_tree2'),
-            ('module', '=', 'analytic_account'),
-            ('inherit', '=', False),
-            ], limit=1, context=context)
-        model_data = model_data_obj.browse(cursor, user, model_data_ids[0],
-                context=context)
-        res = act_window_obj.read(cursor, user, model_data.db_id, context=context)
-        res['context'] = str({
+        act_window_id = model_data_obj.get_id(cursor, user, 'analytic_account',
+                'act_account_tree2', context=context)
+        res = act_window_obj.read(cursor, user, act_window_id, context=context)
+        res['pyson_context'] = PYSONEncoder().encode({
             'start_date': data['form']['start_date'],
-            'end_date': data['form']['end_date']
+            'end_date': data['form']['end_date'],
             })
         return res
 
