@@ -1,10 +1,11 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level
-#of this repository contains the full copyright notices and license terms.
+#This file is part of Tryton.  The COPYRIGHT file at the top level of
+#this repository contains the full copyright notices and license terms.
 "Line"
 from trytond.model import ModelView, ModelSQL, fields
 from trytond.wizard import Wizard
-import mx.DateTime
 from trytond.backend import TableHandler
+from trytond.pyson import Eval, PYSONEncoder
+import time
 
 
 class Line(ModelSQL, ModelView):
@@ -13,15 +14,14 @@ class Line(ModelSQL, ModelView):
     _description = __doc__
 
     name = fields.Char('Name', required=True)
-    debit = fields.Numeric('Debit', digits="(16, currency_digits)",
+    debit = fields.Numeric('Debit', digits=(16, Eval('currency_digits', 2)),
             depends=['currency_digits'])
-    credit = fields.Numeric('Credit', digits="(16, currency_digits)",
+    credit = fields.Numeric('Credit', digits=(16, Eval('currency_digits', 2)),
             depends=['currency_digits'])
-    currency = fields.Function('get_currency', type='many2one',
-            relation='currency.currency', string='Currency',
-            on_change_with=['move_line'])
-    currency_digits = fields.Function('get_currency_digits', type='integer',
-            string='Currency Digits', on_change_with=['move_line'])
+    currency = fields.Function(fields.Many2One('currency.currency', 'Currency',
+        on_change_with=['move_line']), 'get_currency')
+    currency_digits = fields.Function(fields.Integer('Currency Digits',
+        on_change_with=['move_line']), 'get_currency_digits')
     account = fields.Many2One('analytic_account.account', 'Account',
             required=True, select=1, domain=[('type', '!=', 'view')])
     move_line = fields.Many2One('account.move.line', 'Account Move Line',
@@ -63,8 +63,7 @@ class Line(ModelSQL, ModelView):
     def default_active(self, cursor, user, context=None):
         return True
 
-    def on_change_with_currency(self, cursor, user, ids, vals,
-            context=None):
+    def on_change_with_currency(self, cursor, user, vals, context=None):
         move_line_obj = self.pool.get('account.move.line')
         if vals.get('move_line'):
             move_line = move_line_obj.browse(cursor, user, vals['move_line'],
@@ -72,14 +71,13 @@ class Line(ModelSQL, ModelView):
             return move_line.account.company.currency.id
         return False
 
-    def get_currency(self, cursor, user, ids, name, arg, context=None):
+    def get_currency(self, cursor, user, ids, name, context=None):
         res = {}
         for line in self.browse(cursor, user, ids, context=context):
             res[line.id] = line.move_line.account.company.currency.id
         return res
 
-    def on_change_with_currency_digits(self, cursor, user, ids, vals,
-            context=None):
+    def on_change_with_currency_digits(self, cursor, user, vals, context=None):
         move_line_obj = self.pool.get('account.move.line')
         if vals.get('move_line'):
             move_line = move_line_obj.browse(cursor, user, vals['move_line'],
@@ -87,7 +85,7 @@ class Line(ModelSQL, ModelView):
             return move_line.account.company.currency.digits
         return 2
 
-    def get_currency_digits(self, cursor, user, ids, name, arg, context=None):
+    def get_currency_digits(self, cursor, user, ids, name, context=None):
         res = {}
         for line in self.browse(cursor, user, ids, context=context):
             res[line.id] = line.move_line.account.company.currency.digits
@@ -104,12 +102,12 @@ class Line(ModelSQL, ModelView):
         res = obj + '.active'
         if context.get('start_date'):
             # Check start_date
-            mx.DateTime.strptime(str(context['start_date']), '%Y-%m-%d')
+            time.strptime(str(context['start_date']), '%Y-%m-%d')
             res += ' AND ' + obj + '.date >= date(\'' + \
                     str(context['start_date']) + '\')'
         if context.get('end_date'):
             # Check end_date
-            mx.DateTime.strptime(str(context['end_date']), '%Y-%m-%d')
+            time.strptime(str(context['end_date']), '%Y-%m-%d')
             res += ' AND ' + obj + '.date <= date(\'' + \
                     str(context['end_date']) + '\')'
         return res
@@ -153,23 +151,18 @@ class OpenAccount(Wizard):
         if context is None:
             context = {}
 
-        model_data_ids = model_data_obj.search(cursor, user, [
-            ('fs_id', '=', 'act_line_form'),
-            ('module', '=', 'analytic_account'),
-            ('inherit', '=', False),
-            ], limit=1, context=context)
-        model_data = model_data_obj.browse(cursor, user, model_data_ids[0],
-                context=context)
-        res = act_window_obj.read(cursor, user, model_data.db_id, context=context)
-        res['domain'] = [
+        act_window_id = model_data_obj.get_id(cursor, user, 'analytic_account',
+                'act_line_form', context=context)
+        res = act_window_obj.read(cursor, user, act_window_id, context=context)
+        res['pyson_domain'] = [
             ('account', '=', data['id']),
         ]
 
         if context.get('start_date'):
-            res['domain'].append(('date', '>=', context['start_date']))
+            res['pyson_domain'].append(('date', '>=', context['start_date']))
         if context.get('end_date'):
-            res['domain'].append(('date', '<=', context['end_date']))
-        res['domain'] = str(res['domain'])
+            res['pyson_domain'].append(('date', '<=', context['end_date']))
+        res['pyson_domain'] = PYSONEncoder().encode(res['pyson_domain'])
         return res
 
 OpenAccount()
